<?php
namespace FiloBlu\ExtProductVideo\Block\Adminhtml;
use Magento\Backend\Block\Template;
use Magento\Directory\Helper\Data as DirectoryHelper;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Json\Helper\Data as JsonHelper;

class ConfigProvider extends Template
{

    const STOREFRONT_REFILO_URL_PATH = 'web/secure/refilo_storefront_secure_base_url';
    const STOREFRONT_MAGENTO_URL_PATH ='web/secure/base_url';

    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;
    /**
     * @var \Magento\Framework\App\DeploymentConfig
     */
    private $deploymentConfig;

    /**
     * ConfigProvider constructor.
     * @param Template\Context $context
     * @param ScopeConfigInterface $scopeConfig
     * @param \Magento\Framework\App\DeploymentConfig $deploymentConfig
     * @param array $data
     * @param JsonHelper|null $jsonHelper
     * @param DirectoryHelper|null $directoryHelper
     */
    public function __construct(
      Template\Context $context,
      ScopeConfigInterface $scopeConfig,
      \Magento\Framework\App\DeploymentConfig $deploymentConfig,
      array $data = [],
      ?JsonHelper $jsonHelper = null,
      ?DirectoryHelper $directoryHelper = null)
  {
      parent::__construct($context, $data, $jsonHelper, $directoryHelper);
      $this->scopeConfig = $scopeConfig;
      $this->deploymentConfig = $deploymentConfig;
  }

    /**
     * @return mixed
     */
  public function getStorefrontUrl(){
        $baseUrl= $this->scopeConfig->getValue(self::STOREFRONT_REFILO_URL_PATH) ?? $this->scopeConfig->getValue(self::STOREFRONT_REFILO_URL_PATH);
        return $baseUrl.$this->getMediaPath();

  }

    /**
     * @return string
     * @throws \Magento\Framework\Exception\FileSystemException
     * @throws \Magento\Framework\Exception\RuntimeException
     */
  private function getMediaPath(){
      $documentRoot = $this->deploymentConfig->getConfigData('directories')['document_root_is_pub'] ?? true;
      if($documentRoot){
          return '';
      }else{
          return 'pub/';
      }
  }

}
